"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAppBaseUrl = exports.clearIsInSourceDirCachedValue = exports.isInSourceDirectory = exports.clearAppRootDirectoryCache = exports.getAppRootDirectory = exports.getServerDirectory = exports.setServerDirectory = void 0;
const path_1 = __importDefault(require("path"));
const config_1 = require("@men-mvc/config");
const types_1 = require("../types");
const setServerDirectory = (dir) => (0, config_1.setEnvVariable)('SERVER_DIRECTORY', dir);
exports.setServerDirectory = setServerDirectory;
const getServerDirectory = () => (0, config_1.getEnvVariable)('SERVER_DIRECTORY', '') ?? ``;
exports.getServerDirectory = getServerDirectory;
let cachedAppRootDirectory = null;
const getAppRootDirectory = () => {
    if (cachedAppRootDirectory) {
        return cachedAppRootDirectory;
    }
    let serverDirectory = (0, exports.getServerDirectory)();
    if (!serverDirectory) {
        throw new Error(`Unable to get app project directory as the server directory is not set.`);
    }
    if (!(0, exports.isInSourceDirectory)()) {
        // for prod build, server directory is the app root directory
        cachedAppRootDirectory = serverDirectory;
        return cachedAppRootDirectory;
    }
    // path will end with src as isInSourceDirectory returns true
    if (serverDirectory.endsWith(path_1.default.sep)) {
        serverDirectory = serverDirectory.slice(0, -1);
    }
    const segments = serverDirectory.split(path_1.default.sep);
    segments.pop(); // remove the src
    cachedAppRootDirectory = segments.join(path_1.default.sep);
    return cachedAppRootDirectory;
};
exports.getAppRootDirectory = getAppRootDirectory;
const clearAppRootDirectoryCache = () => {
    cachedAppRootDirectory = null;
};
exports.clearAppRootDirectoryCache = clearAppRootDirectoryCache;
// if the server is inside the /src folder, this function returns true.
let isInSourceDirCachedValue = null;
const isInSourceDirectory = () => {
    if (isInSourceDirCachedValue !== null) {
        return isInSourceDirCachedValue;
    }
    let serverDir = (0, exports.getServerDirectory)();
    if (!serverDir) {
        throw new Error(`Application server is missing.`);
    }
    if (serverDir.endsWith(path_1.default.sep)) {
        serverDir = serverDir.slice(0, -1); // remove the last character which is path.sep
    }
    const segments = serverDir.split(path_1.default.sep);
    let lastSegment = segments[segments.length - 1];
    if (!lastSegment) {
        throw new Error(`Application server does not exist in the src or dist folder.`);
    }
    isInSourceDirCachedValue = lastSegment.toLowerCase() === config_1.srcDirectory;
    return isInSourceDirCachedValue;
};
exports.isInSourceDirectory = isInSourceDirectory;
const clearIsInSourceDirCachedValue = () => {
    isInSourceDirCachedValue = null;
};
exports.clearIsInSourceDirCachedValue = clearIsInSourceDirCachedValue;
const getAppBaseUrl = () => {
    if ((0, config_1.getEnvVariable)(`APP_BASE_URL`)) {
        return (0, config_1.getEnvVariable)(`APP_BASE_URL`);
    }
    const req = types_1.BaseApplication.getInstance().getCurrentRequest();
    return req.protocol + '://' + req.get('host');
};
exports.getAppBaseUrl = getAppBaseUrl;
