"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asyncRequestHandler = exports.requestHandler = exports.extractBearerToken = void 0;
const extractBearerToken = (request) => {
    const authHeader = request.header('Authorization');
    if (!authHeader) {
        return null;
    }
    const tokens = authHeader.split(' ');
    if (tokens.length !== 2) {
        return null;
    }
    if (tokens[0] !== 'Bearer') {
        return null;
    }
    return tokens[1] ? tokens[1] : null;
};
exports.extractBearerToken = extractBearerToken;
const requestHandler = (fn) => {
    return (wrapperReq, wrapperRes, wrapperNext) => {
        try {
            fn(wrapperReq, wrapperRes, wrapperNext);
        }
        catch (e) {
            return wrapperNext(e);
        }
    };
};
exports.requestHandler = requestHandler;
const asyncRequestHandler = (fn) => {
    return async (wrapperReq, wrapperRes, wrapperNext) => {
        try {
            await fn(wrapperReq, wrapperRes, wrapperNext);
        }
        catch (e) {
            return wrapperNext(e);
        }
    };
};
exports.asyncRequestHandler = asyncRequestHandler;
