"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.insufficientPermissionsResponse = exports.unauthorisedErrorResponse = exports.validationErrorResponse = exports.emptyResponse = exports.notFoundResponse = exports.errorResponse = exports.successResponse = void 0;
const types_1 = require("../types");
const successResponse = (res, data, status = types_1.StatusCodes.OK) => {
    return res.status(status).json({
        data
    });
};
exports.successResponse = successResponse;
const errorResponse = (res, error, status) => {
    let responseData;
    if (typeof error === 'string') {
        responseData = {
            message: error
        };
    }
    else {
        responseData = {
            message: error.message
        };
        if (error.code) {
            responseData.code = error.code;
        }
        if (error.details) {
            responseData.details = error.details;
        }
    }
    return res.status(status).json(new types_1.ErrorResponse(responseData));
};
exports.errorResponse = errorResponse;
const notFoundResponse = (res, error) => {
    return (0, exports.errorResponse)(res, error, types_1.StatusCodes.NOT_FOUND);
};
exports.notFoundResponse = notFoundResponse;
const emptyResponse = (res, status = types_1.StatusCodes.NO_CONTENT) => {
    return res.status(status).json(null);
};
exports.emptyResponse = emptyResponse;
const validationErrorResponse = (res, validationError) => {
    return res
        .status(types_1.StatusCodes.UNPROCESSABLE_ENTITY)
        .json(new types_1.ValidationErrorResponse(validationError));
};
exports.validationErrorResponse = validationErrorResponse;
const unauthorisedErrorResponse = (res, message) => {
    return (0, exports.errorResponse)(res, {
        message: message ?? `Unauthorised.`
    }, types_1.StatusCodes.UNAUTHORIZED);
};
exports.unauthorisedErrorResponse = unauthorisedErrorResponse;
const insufficientPermissionsResponse = (res, error) => {
    return (0, exports.errorResponse)(res, {
        code: error.name,
        message: error.message
    }, types_1.StatusCodes.FORBIDDEN);
};
exports.insufficientPermissionsResponse = insufficientPermissionsResponse;
